@@ -29,6 +29,7 @@ class FileNameEnum:
         GetFeatureVariableValue = API_PATH + "get_feature_variable_value"
         Push = API_PATH + "push"
         Launch = API_PATH + "launch"
+        FlushEvents = API_PATH + "flush_events"
         GetAndUpdateSettingsFile = API_PATH + "get_and_update_settings_file"
 
     class Core:
@@ -58,3 +59,4 @@ class FileNameEnum:
         SERVICES_PATH = "vwo/services/"
         SettingsFileManager = SERVICES_PATH + "settings_file_manager"
         SegmentEvaluator = SERVICES_PATH + "segment_evaluator"
+        HooksManager = SERVICES_PATH + "hooks_manager"
